#ifndef TG4_VERSION_H
#define TG4_VERSION_H

//------------------------------------------------
// The Geant4 Virtual Monte Carlo package
// Copyright (C) 2014 - 2018 Ivana Hrivnacova
// All rights reserved.
//
// For the licensing terms see geant4_vmc/LICENSE.
// Contact: root-vmc@cern.ch
//-------------------------------------------------

/// \file TG4Version.h
/// \brief Definition of the code version and release date
///
/// \author I. Hrivnacova; IPN, Orsay

#define GEANT4_VMC_RELEASE "6.7.p1"
#define GEANT4_VMC_RELEASE_DATE "1 April 2025"

#endif // TG4_VERSION_H
